@@ -44,7 +44,7 @@ static struct GNUNET_NAMESTORE_Handle *ns;
 /**
  * Private key for the our zone.
  */
-static struct GNUNET_CRYPTO_PrivateKey zone_pkey;
+static struct GNUNET_CRYPTO_BlindablePrivateKey zone_pkey;
 
 /**
  * EgoLookup
@@ -99,12 +99,12 @@ static char *expiration;
 /**
  * Subject key
  */
-struct GNUNET_CRYPTO_PublicKey subject_pkey;
+struct GNUNET_CRYPTO_BlindablePublicKey subject_pkey;
 
 /**
  * Issuer key
  */
-struct GNUNET_CRYPTO_PublicKey issuer_pkey;
+struct GNUNET_CRYPTO_BlindablePublicKey issuer_pkey;
 
 
 /**
@@ -278,9 +278,9 @@ handle_intermediate_result (void *cls,
 
   printf ("%s Intermediate result: %s.%s <- %s.%s\n",
           prefix,
-          GNUNET_CRYPTO_public_key_to_string (&dd->issuer_key),
+          GNUNET_CRYPTO_blindable_public_key_to_string (&dd->issuer_key),
           dd->issuer_attribute,
-          GNUNET_CRYPTO_public_key_to_string (&dd->subject_key),
+          GNUNET_CRYPTO_blindable_public_key_to_string (&dd->subject_key),
           dd->subject_attribute);
 }
 
@@ -333,8 +333,10 @@ handle_verify_result (void *cls,
     printf ("Delegation Chain:\n");
     for (i = 0; i < d_count; i++)
     {
-      iss_key = GNUNET_CRYPTO_public_key_to_string (&dc[i].issuer_key);
-      sub_key = GNUNET_CRYPTO_public_key_to_string (&dc[i].subject_key);
+      iss_key = GNUNET_CRYPTO_blindable_public_key_to_string (&dc[i].issuer_key)
+      ;
+      sub_key = GNUNET_CRYPTO_blindable_public_key_to_string (&dc[i].subject_key
+                                                              );
 
       if (0 != dc[i].subject_attribute_len)
       {
@@ -359,8 +361,10 @@ handle_verify_result (void *cls,
     printf ("\nDelegate(s):\n");
     for (i = 0; i < c_count; i++)
     {
-      iss_key = GNUNET_CRYPTO_public_key_to_string (&dele[i].issuer_key);
-      sub_key = GNUNET_CRYPTO_public_key_to_string (&dele[i].subject_key);
+      iss_key = GNUNET_CRYPTO_blindable_public_key_to_string (&dele[i].
+                                                              issuer_key);
+      sub_key = GNUNET_CRYPTO_blindable_public_key_to_string (&dele[i].
+                                                              subject_key);
       printf ("%s.%s <- %s\n", iss_key, dele[i].issuer_attribute, sub_key);
       GNUNET_free (iss_key);
       GNUNET_free (sub_key);
@@ -382,7 +386,7 @@ handle_verify_result (void *cls,
 static void
 identity_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 {
-  const struct GNUNET_CRYPTO_PrivateKey *privkey;
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *privkey;
 
   el = NULL;
   if (NULL == ego)
@@ -401,8 +405,8 @@ identity_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
   {
 
     if (GNUNET_OK !=
-        GNUNET_CRYPTO_public_key_from_string (issuer_key,
-                                              &issuer_pkey))
+        GNUNET_CRYPTO_blindable_public_key_from_string (issuer_key,
+                                                        &issuer_pkey))
     {
       fprintf (stderr,
                _ ("Issuer public key `%s' is not well-formed\n"),
@@ -502,7 +506,7 @@ add_continuation (void *cls, enum GNUNET_ErrorCode ec)
 
 static void
 get_existing_record (void *cls,
-                     const struct GNUNET_CRYPTO_PrivateKey *zone_key,
+                     const struct GNUNET_CRYPTO_BlindablePrivateKey *zone_key,
                      const char *rec_name,
                      unsigned int rd_count,
                      const struct GNUNET_GNSRECORD_Data *rd)
@@ -546,7 +550,7 @@ store_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 {
   const struct GNUNET_CONFIGURATION_Handle *cfg_ = cls;
   struct GNUNET_ABD_Delegate *cred;
-  struct GNUNET_CRYPTO_PublicKey zone_pubkey;
+  struct GNUNET_CRYPTO_BlindablePublicKey zone_pubkey;
   char *subject_pubkey_str;
   char *zone_pubkey_str;
 
@@ -587,12 +591,12 @@ store_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 
     // Get import subject public key string
     subject_pubkey_str =
-      GNUNET_CRYPTO_public_key_to_string (&cred->subject_key);
+      GNUNET_CRYPTO_blindable_public_key_to_string (&cred->subject_key);
 
     // Get zone public key string
     GNUNET_IDENTITY_ego_get_public_key (ego, &zone_pubkey);
     zone_pubkey_str =
-      GNUNET_CRYPTO_public_key_to_string (&zone_pubkey);
+      GNUNET_CRYPTO_blindable_public_key_to_string (&zone_pubkey);
 
     // Check if the subject key in the signed import matches the zone's key it is issued to
     if (strcmp (zone_pubkey_str, subject_pubkey_str) != 0)
@@ -670,7 +674,7 @@ store_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 static void
 sign_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
 {
-  const struct GNUNET_CRYPTO_PrivateKey *privkey;
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *privkey;
   struct GNUNET_ABD_Delegate *dele;
   struct GNUNET_TIME_Absolute etime_abs;
   char *res;
@@ -720,8 +724,8 @@ sign_cb (void *cls, struct GNUNET_IDENTITY_Ego *ego)
     return;
   }
   if (GNUNET_OK !=
-      GNUNET_CRYPTO_public_key_from_string (subject_pubkey_str,
-                                            &subject_pkey))
+      GNUNET_CRYPTO_blindable_public_key_from_string (subject_pubkey_str,
+                                                      &subject_pkey))
   {
     fprintf (stderr,
              "Subject public key `%s' is not well-formed\n",
@@ -885,8 +889,9 @@ run (void *cls,
     GNUNET_SCHEDULER_shutdown ();
     return;
   }
-  if (GNUNET_OK != GNUNET_CRYPTO_public_key_from_string (subject,
-                                                         &subject_pkey))
+  if (GNUNET_OK != GNUNET_CRYPTO_blindable_public_key_from_string (subject,
+                                                                   &subject_pkey
+                                                                   ))
   {
     fprintf (stderr,
              _ ("Subject public key `%s' is not well-formed\n"),
@@ -904,8 +909,8 @@ run (void *cls,
       return;
     }
     if (GNUNET_OK !=
-        GNUNET_CRYPTO_public_key_from_string (issuer_key,
-                                              &issuer_pkey))
+        GNUNET_CRYPTO_blindable_public_key_from_string (issuer_key,
+                                                        &issuer_pkey))
     {
       fprintf (stderr,
                _ ("Issuer public key `%s' is not well-formed\n"),
@@ -1094,7 +1099,7 @@ main (int argc, char *const *argv)
 
   timeout = GNUNET_TIME_UNIT_FOREVER_REL;
   GNUNET_log_setup ("gnunet-abd", "WARNING", NULL);
-  if (GNUNET_OK != GNUNET_PROGRAM_run (GNUNET_OS_project_data_gnunet(),
+  if (GNUNET_OK != GNUNET_PROGRAM_run (GNUNET_OS_project_data_gnunet (),
                                        argc,
                                        argv,
                                        "gnunet-abd",
