@@ -65,9 +65,9 @@ extern "C" {
 
 
 /**
- * Signature for confirming a key revocation. (GNUnet-Revocation)
+ * GNS zone key revocation (GNS)
  */
-#define GNUNET_SIGNATURE_PURPOSE_REVOCATION 3
+#define GNUNET_SIGNATURE_PURPOSE_GNS_REVOCATION 3
 
 
 /**
@@ -119,7 +119,7 @@ extern "C" {
 
 
 /**
- * Signature of a gnunet naming system record block (GNUnet-GNSRECORD)
+ * GNS record set signature (GNS)
  */
 #define GNUNET_SIGNATURE_PURPOSE_GNS_RECORD_SIGN 15
 
