@@ -25,6 +25,7 @@
  * @author Christian Grothoff
  */
 #include "platform.h"
+#include "gnunet_util_lib.h"
 #include "gnunet_json_lib.h"
 #include "gnunet_common.h"
 
@@ -1833,4 +1834,61 @@ GNUNET_JSON_spec_unblinded_signature (const char *field,
 }
 
 
+/**
+ * Parse given JSON object to `enum GNUNET_TIME_RounderInterval`
+ *
+ * @param cls closure, NULL
+ * @param root the json object representing data
+ * @param[out] spec where to write the data
+ * @return #GNUNET_OK upon successful parsing; #GNUNET_SYSERR upon error
+ */
+static enum GNUNET_GenericReturnValue
+parse_tri (void *cls,
+           json_t *root,
+           struct GNUNET_JSON_Specification *spec)
+{
+  enum GNUNET_TIME_RounderInterval *res
+    = (enum GNUNET_TIME_RounderInterval *) spec->ptr;
+
+  (void) cls;
+  if (json_is_string (root))
+  {
+    const char *str;
+
+    str = json_string_value (root);
+    if (NULL == str)
+    {
+      GNUNET_break_op (0);
+      return GNUNET_SYSERR;
+    }
+    if (GNUNET_OK !=
+        GNUNET_TIME_string_to_round_interval (str,
+                                              res))
+    {
+      GNUNET_break_op (0);
+      return GNUNET_SYSERR;
+    }
+    return GNUNET_OK;
+  }
+  return GNUNET_SYSERR;
+}
+
+
+struct GNUNET_JSON_Specification
+GNUNET_JSON_spec_time_rounder_interval (
+  const char *name,
+  enum GNUNET_TIME_RounderInterval *ri)
+{
+  struct GNUNET_JSON_Specification ret = {
+    .parser = &parse_tri,
+    .field = name,
+    .ptr = ri
+  };
+
+  *ri = GNUNET_TIME_RI_NONE;
+  return ret;
+
+}
+
+
 /* end of json_helper.c */
