@@ -29,7 +29,6 @@
 #include "gnunet-service-core.h"
 #include "gnunet-service-core_kx.h"
 #include "gnunet-service-core_sessions.h"
-#include "gnunet-service-core_typemap.h"
 #include "gnunet_constants.h"
 
 /**
@@ -48,6 +47,8 @@
 #define HARD_MAX_QUEUE 256
 
 
+struct GSC_ServicesInfo;
+
 /**
  * Data structure for each client connected to the CORE service.
  */
@@ -121,11 +122,21 @@ struct GNUNET_PeerIdentity GSC_my_identity;
  */
 const struct GNUNET_CONFIGURATION_Handle *GSC_cfg;
 
+/**
+ * Handle to the running service.
+ */
+struct GNUNET_SERVICE_Handle *service_h;
+
 /**
  * For creating statistics.
  */
 struct GNUNET_STATISTICS_Handle *GSC_stats;
 
+/**
+ * Our peer class
+ */
+static enum GNUNET_CORE_PeerClass GSC_peer_class;
+
 /**
  * Big "or" of all client options.
  */
@@ -141,6 +152,134 @@ static struct GSC_Client *client_head;
  */
 static struct GSC_Client *client_tail;
 
+// TODO
+static struct GSC_ServicesInfo *own_services;
+
+/*************************************
+ *       Services Info Utils        *
+ ************************************/
+
+// TODO put into gnunet-service-core_services_info.[h|c]
+// TODO write its own test
+// TODO rewrite: don't keep the big string, have only a known data structure
+//      (DLL? array?) have a from_string() and a to_string()
+
+// TODO
+struct GSC_ServicesInfo_Entry
+{
+  // TODO
+  // pointer to the beginning of service name
+  char *name; // TODO find syntax to set array size to num_entries
+  // TODO
+  uint32_t name_len;
+  // TODO
+  // pointer to the beginning of service version
+  char *version; // TODO find syntax to set array size to num_entries
+  // TODO
+  uint32_t version_len;
+};
+
+// TODO
+struct GSC_ServicesInfo
+{
+  // TODO
+  uint32_t num_entries;
+
+  // TODO
+  struct GSC_ServicesInfo_Entry *entries;
+};
+
+// TODO
+// (?) _remove()
+// (?) _iter()
+
+// TODO
+static struct GSC_ServicesInfo *
+GSC_SVCI_init ()
+{
+  struct GSC_ServicesInfo *services_info = GNUNET_new (struct GSC_ServicesInfo);
+  services_info->num_entries = 0;
+  services_info->entries = NULL;
+  return services_info;
+}
+
+
+// TODO
+static void
+GSC_SVCI_destroy (struct GSC_ServicesInfo *services_info)
+{
+  GNUNET_assert (NULL != services_info);
+  GNUNET_free (services_info);
+}
+
+
+// TODO
+// todo check string size while adding!
+static void
+GSC_SVCI_add (struct GSC_ServicesInfo *services,
+              char *name, uint32_t name_len,
+              char *version, uint32_t version_len)
+{
+  struct GSC_ServicesInfo_Entry *entry;
+
+  GNUNET_array_grow (services->entries, services->num_entries, 1);
+  entry = &services->entries[services->num_entries - 1];
+  entry->name = GNUNET_strdup (name);
+  entry->name_len = name_len;
+  entry->version = GNUNET_strdup (version);
+  entry->version_len = version_len;
+}
+
+
+// TODO
+static void
+GSC_SVCI_remove (struct GSC_ServicesInfo *services,
+                 char *name, uint32_t name_len)
+{
+  struct GSC_ServicesInfo_Entry *entry;
+  uint64_t i_entry;
+
+  /* Find element */
+  entry = NULL;
+  for (uint64_t i = 0; i < services->num_entries; i++)
+  {
+    if (services->entries[i].name_len != name_len)
+      continue;
+    if (0 == memcmp (&services->entries[i].name, name, name_len))
+    {
+      entry = &services->entries[i];
+      i_entry = i;
+      break;
+    }
+  }
+  if (NULL == entry)
+  {
+    /* No matching entry was found!*/
+    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                "No matching service entry `%s' was found in services info.\n",
+                name);
+    return;
+  }
+
+  /* Remove element */
+  GNUNET_free (entry->name);
+  GNUNET_free (entry->version);
+  for (uint64_t i = i_entry; i < services->num_entries - 1; i++)
+  {
+    GNUNET_memcpy (&services->entries[i],
+                   &services->entries[i + 1],
+                   sizeof (services->entries[i + 1]));
+  }
+  GNUNET_array_grow (services->entries,
+                     services->num_entries,
+                     services->num_entries - 1);
+}
+
+
+/*************************************
+ *    End of Services Info Utils    *
+ ************************************/
+
 
 /**
  * Test if the client is interested in messages of the given type.
@@ -209,15 +348,22 @@ handle_client_init (void *cls, const struct InitMessage *im)
                    GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
   for (unsigned int i = 0; i < c->tcnt; i++)
     c->types[i] = ntohs (types[i]);
-  GSC_TYPEMAP_add (c->types, c->tcnt);
+  // TODO
+  GSC_SVCI_add (own_services, "example", 7, "0.1", 3);
   GNUNET_log (
     GNUNET_ERROR_TYPE_DEBUG,
     "Client connecting to core service is interested in %u message types\n",
     (unsigned int) c->tcnt);
+  for (unsigned int i = 0; i < c->tcnt; i++)
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+                "  type[%u]: %u\n",
+                i,
+                c->types[i]);
   /* send init reply message */
   env = GNUNET_MQ_msg (irm, GNUNET_MESSAGE_TYPE_CORE_INIT_REPLY);
   irm->reserved = htonl (0);
   irm->my_identity = GSC_my_identity;
+  irm->class = GSC_peer_class;
   GNUNET_MQ_send (c->mq, env);
   GSC_SESSIONS_notify_client_about_sessions (c);
   GNUNET_SERVICE_client_continue (c->client);
@@ -500,7 +646,8 @@ handle_client_send (void *cls, const struct SendMessage *sm)
      * (which triggered removal of the 'car') and now the client gives us a message
      * just *before* the client learns about the disconnect.  Theoretically, we
      * might also now be *again* connected.  So this can happen (but should be
-     * rare).  If it does happen, the message is discarded. */GNUNET_STATISTICS_update (GSC_stats,
+     * rare).  If it does happen, the message is discarded. */
+    GNUNET_STATISTICS_update (GSC_stats,
                               gettext_noop (
                                 "# messages discarded (session disconnected)"),
                               1,
@@ -616,12 +763,8 @@ client_disconnect_cb (void *cls,
   }
   GNUNET_CONTAINER_multipeermap_destroy (c->connectmap);
   c->connectmap = NULL;
-  if (NULL != c->types)
-  {
-    GSC_TYPEMAP_remove (c->types, c->tcnt);
-    GNUNET_free (c->types);
-  }
-  GNUNET_free (c);
+  // TODO
+  GSC_SVCI_remove (own_services, "example", 7);
 
   /* recalculate 'all_client_options' */
   all_client_options = 0;
@@ -639,76 +782,62 @@ client_disconnect_cb (void *cls,
  * @param neighbour identity of the neighbour that changed status
  * @param tmap_old previous type map for the neighbour, NULL for connect
  * @param tmap_new updated type map for the neighbour, NULL for disconnect
+ * @param class the class of the neighbour that changed status
  */
 void
 GSC_CLIENTS_notify_client_about_neighbour (
   struct GSC_Client *client,
   const struct GNUNET_PeerIdentity *neighbour,
-  const struct GSC_TypeMap *tmap_old,
-  const struct GSC_TypeMap *tmap_new)
+  enum GNUNET_CORE_PeerClass class)
 {
   struct GNUNET_MQ_Envelope *env;
-  int old_match;
-  int new_match;
+  struct ConnectNotifyMessage *cnm;
 
   if (GNUNET_YES != client->got_init)
     return;
-  old_match = GSC_TYPEMAP_test_match (tmap_old, client->types, client->tcnt);
-  new_match = GSC_TYPEMAP_test_match (tmap_new, client->types, client->tcnt);
+  // TODO
+  // GSC_SVCI_contains (own_services, "example", 7);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "Notifying client about neighbour %s (%d/%d)\n",
-              GNUNET_i2s (neighbour),
-              old_match,
-              new_match);
-  if (old_match == new_match)
-  {
-    GNUNET_assert (
-      old_match ==
-      GNUNET_CONTAINER_multipeermap_contains (client->connectmap, neighbour));
-    return;   /* no change */
-  }
-  if (GNUNET_NO == old_match)
-  {
-    struct ConnectNotifyMessage *cnm;
+              "Notifying client about neighbour %s\n",
+              GNUNET_i2s (neighbour));
 
-    /* send connect */
-    GNUNET_assert (
-      GNUNET_NO ==
-      GNUNET_CONTAINER_multipeermap_contains (client->connectmap, neighbour));
-    GNUNET_assert (GNUNET_YES ==
-                   GNUNET_CONTAINER_multipeermap_put (
-                     client->connectmap,
-                     neighbour,
-                     NULL,
-                     GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
-    env = GNUNET_MQ_msg (cnm, GNUNET_MESSAGE_TYPE_CORE_NOTIFY_CONNECT);
-    cnm->reserved = htonl (0);
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "Sending NOTIFY_CONNECT message about peer %s to client.\n",
-                GNUNET_i2s (neighbour));
-    cnm->peer = *neighbour;
-    GNUNET_MQ_send (client->mq, env);
-  }
-  else
+  /* send connect */
+  //  TODO this used to be an assert. evaluate what handling makes sense here.
+  if (GNUNET_YES == GNUNET_CONTAINER_multipeermap_contains (client->connectmap,
+                                                            neighbour))
   {
-    struct DisconnectNotifyMessage *dcm;
-
-    /* send disconnect */
-    GNUNET_assert (
-      GNUNET_YES ==
-      GNUNET_CONTAINER_multipeermap_contains (client->connectmap, neighbour));
-    GNUNET_assert (GNUNET_YES ==
-                   GNUNET_CONTAINER_multipeermap_remove (client->connectmap,
-                                                         neighbour,
-                                                         NULL));
-    env = GNUNET_MQ_msg (dcm, GNUNET_MESSAGE_TYPE_CORE_NOTIFY_DISCONNECT);
-    dcm->reserved = htonl (0);
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "Sending NOTIFY_DISCONNECT message about peer %s to client.\n",
-                GNUNET_i2s (neighbour));
-    dcm->peer = *neighbour;
-    GNUNET_MQ_send (client->mq, env);
+    return;
   }
+  GNUNET_assert (GNUNET_YES ==
+                 GNUNET_CONTAINER_multipeermap_put (
+                   client->connectmap,
+                   neighbour,
+                   NULL,
+                   GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
+  env = GNUNET_MQ_msg (cnm, GNUNET_MESSAGE_TYPE_CORE_NOTIFY_CONNECT);
+  cnm->reserved = htonl (0);
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
+              "Sending NOTIFY_CONNECT message about peer %s to client.\n",
+              GNUNET_i2s (neighbour));
+  cnm->peer = *neighbour;
+  cnm->peer_class = class;
+  GNUNET_MQ_send (client->mq, env);
+}
+
+
+/**
+ * This function is called from GSC_KX_init() once it got its peer id from
+ * pils.
+ * @param cls closure to the callback
+ */
+void
+GSC_complete_initialization_cb (void)
+{
+  GSC_SESSIONS_init ();
+  GNUNET_SERVICE_resume (service_h);
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              _ ("Core service of `%s' ready.\n"),
+              GNUNET_i2s (&GSC_my_identity));
 }
 
 
@@ -720,20 +849,19 @@ GSC_CLIENTS_notify_client_about_neighbour (
  * @param neighbour identity of the neighbour that changed status
  * @param tmap_old previous type map for the neighbour, NULL for connect
  * @param tmap_new updated type map for the neighbour, NULL for disconnect
+ * @param class the class of the neighbour that changed status
  */
 void
 GSC_CLIENTS_notify_clients_about_neighbour (
   const struct GNUNET_PeerIdentity *neighbour,
-  const struct GSC_TypeMap *tmap_old,
-  const struct GSC_TypeMap *tmap_new)
+  enum GNUNET_CORE_PeerClass class)
 {
   struct GSC_Client *c;
 
   for (c = client_head; NULL != c; c = c->next)
     GSC_CLIENTS_notify_client_about_neighbour (c,
                                                neighbour,
-                                               tmap_old,
-                                               tmap_new);
+                                               class);
 }
 
 
@@ -763,12 +891,15 @@ GSC_CLIENTS_deliver_message (const struct GNUNET_PeerIdentity *sender,
   }
   if (! ((0 != (all_client_options & options)) ||
          (0 != (options & GNUNET_CORE_OPTION_SEND_FULL_INBOUND))))
+  {
     return; /* no client cares about this message notification */
+  }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Core service passes message from `%s' of type %u to client.\n",
               GNUNET_i2s (sender),
               (unsigned int) ntohs (msg->type));
-  GSC_SESSIONS_add_to_typemap (sender, ntohs (msg->type));
+  // TODO
+  // GSC_SVCI_add (sender->services, "example", 7, "0.1", 3);
 
   for (struct GSC_Client *c = client_head; NULL != c; c = c->next)
   {
@@ -869,7 +1000,7 @@ shutdown_task (void *cls)
     GNUNET_SERVICE_client_drop (c->client);
   GSC_SESSIONS_done ();
   GSC_KX_done ();
-  GSC_TYPEMAP_done ();
+  GSC_SVCI_destroy (own_services);
   if (NULL != GSC_stats)
   {
     GNUNET_STATISTICS_destroy (GSC_stats, GNUNET_NO);
@@ -911,48 +1042,57 @@ run (void *cls,
      const struct GNUNET_CONFIGURATION_Handle *c,
      struct GNUNET_SERVICE_Handle *service)
 {
-  struct GNUNET_CRYPTO_EddsaPrivateKey pk;
-  char *keyfile;
-
   GSC_cfg = c;
-  if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_filename (GSC_cfg,
-                                               "PEER",
-                                               "PRIVATE_KEY",
-                                               &keyfile))
-  {
-    GNUNET_log (
-      GNUNET_ERROR_TYPE_ERROR,
-      _ ("Core service is lacking HOSTKEY configuration setting.  Exiting.\n"));
-    GNUNET_SCHEDULER_shutdown ();
-    return;
-  }
+  service_h = service;
   GSC_stats = GNUNET_STATISTICS_create ("core", GSC_cfg);
+  {
+    /* Read the peer class from the configuration */
+    const char *peer_class_str = "UNKNOWN";
+    const char *choices[] = {
+      "UNKNOWN",
+      "UNWILLING",
+      "MOBILE",
+      "DESKTOP",
+      "ROUTER",
+      "SERVER",
+      NULL
+    };
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Starting CORE service\n");
+    if (GNUNET_OK !=
+        GNUNET_CONFIGURATION_get_value_choice (c,
+                                               "core",
+                                               "CLASS",
+                                               choices,
+                                               &peer_class_str))
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "No class found in configuration! (Continuing with unknown class)");
+      GSC_peer_class = GNUNET_CORE_CLASS_UNKNOWN;
+    }
+    if (0 == strcasecmp (peer_class_str, "UNKNOWN"))
+      GSC_peer_class = GNUNET_CORE_CLASS_UNKNOWN;
+    else if (0 == strcasecmp (peer_class_str, "UNWILLING"))
+      GSC_peer_class = GNUNET_CORE_CLASS_UNWILLING;
+    else if (0 == strcasecmp (peer_class_str, "MOBILE"))
+      GSC_peer_class = GNUNET_CORE_CLASS_MOBILE;
+    else if (0 == strcasecmp (peer_class_str, "DESKTOP"))
+      GSC_peer_class = GNUNET_CORE_CLASS_DESKTOP;
+    else if (0 == strcasecmp (peer_class_str, "ROUTER"))
+      GSC_peer_class = GNUNET_CORE_CLASS_ROUTER;
+    else if (0 == strcasecmp (peer_class_str, "SERVER"))
+      GSC_peer_class = GNUNET_CORE_CLASS_SERVER;
+    else
+      GNUNET_assert (0);
+  }
   GNUNET_SCHEDULER_add_shutdown (&shutdown_task, NULL);
   GNUNET_SERVICE_suspend (service);
-  GSC_TYPEMAP_init ();
-  if (GNUNET_SYSERR ==
-      GNUNET_CRYPTO_eddsa_key_from_file (keyfile,
-                                         GNUNET_YES,
-                                         &pk))
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed to setup peer's private key\n");
-    GNUNET_SCHEDULER_shutdown ();
-    GNUNET_free (keyfile);
-    return;
-  }
-  GNUNET_free (keyfile);
-  if (GNUNET_OK != GSC_KX_init (&pk))
+  own_services = GSC_SVCI_init ();
+  if (GNUNET_OK != GSC_KX_init ())
   {
     GNUNET_SCHEDULER_shutdown ();
     return;
   }
-  GSC_SESSIONS_init ();
-  GNUNET_SERVICE_resume (service);
-  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-              _ ("Core service of `%s' ready.\n"),
-              GNUNET_i2s (&GSC_my_identity));
 }
 
 
@@ -960,7 +1100,7 @@ run (void *cls,
  * Define "main" method using service macro.
  */
 GNUNET_SERVICE_MAIN (
-  GNUNET_OS_project_data_gnunet(),
+  GNUNET_OS_project_data_gnunet (),
   "core",
   GNUNET_SERVICE_OPTION_NONE,
   &run,
