@@ -296,7 +296,7 @@ create_response (void *cls,
                  size_t *upload_data_size,
                  void **ptr)
 {
-  struct GNUNET_CRYPTO_PublicKey pk;
+  struct GNUNET_CRYPTO_BlindablePublicKey pk;
   bool isget = (0 == strcmp (method, MHD_HTTP_METHOD_GET));
   bool ishead = (0 == strcmp (method, MHD_HTTP_METHOD_HEAD));
   bool isfull = (0 == strcmp ("/submit/full", url));
@@ -370,7 +370,8 @@ create_response (void *cls,
 
 
   if (NULL == gnskey
-      || GNUNET_OK != GNUNET_CRYPTO_public_key_from_string (gnskey, &pk))
+      || GNUNET_OK != GNUNET_CRYPTO_blindable_public_key_from_string (gnskey, &
+                                                                      pk))
   {
     return MHD_queue_response (connection,
                                MHD_HTTP_BAD_REQUEST,
