@@ -557,7 +557,7 @@ identity_cb (void *cls,
              void **ctx,
              const char *name)
 {
-  const struct GNUNET_CRYPTO_PrivateKey *zone_key;
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *zone_key;
   struct GNUNET_GNSRECORD_Data rd;
   char *rd_string;
   char *peername;
@@ -824,7 +824,8 @@ main (int argc,
        (GNUNET_YES !=
         GNUNET_OS_check_helper_binary (bin_exit,
                                        GNUNET_YES,
-                                       "-d gnunet-vpn - - - 169.1.3.3.7 255.255.255.0"))))     // no nat, ipv4 only
+                                       "-d gnunet-vpn - - - 169.1.3.3.7 255.255.255.0"))))
+  // no nat, ipv4 only
   {
     fprintf (stderr,
              "WARNING: gnunet-helper-{exit,vpn} binaries in $PATH are not SUID, refusing to run test (as it would have to fail).\n");
