@@ -233,7 +233,7 @@ struct GNUNET_RECLAIM_AttributeIterator
   /**
    * Private key of the zone.
    */
-  struct GNUNET_CRYPTO_PrivateKey identity;
+  struct GNUNET_CRYPTO_BlindablePrivateKey identity;
 
   /**
    * The operation id this zone iteration operation has
@@ -300,7 +300,7 @@ struct GNUNET_RECLAIM_CredentialIterator
   /**
    * Private key of the zone.
    */
-  struct GNUNET_CRYPTO_PrivateKey identity;
+  struct GNUNET_CRYPTO_BlindablePrivateKey identity;
 
   /**
    * The operation id this zone iteration operation has
@@ -591,7 +591,7 @@ static void
 handle_consume_ticket_result (void *cls,
                               const struct ConsumeTicketResultMessage *msg)
 {
-  struct GNUNET_CRYPTO_PublicKey identity;
+  struct GNUNET_CRYPTO_BlindablePublicKey identity;
   struct GNUNET_RECLAIM_Handle *h = cls;
   struct GNUNET_RECLAIM_Operation *op;
   size_t attrs_len;
@@ -714,7 +714,7 @@ check_attribute_result (void *cls, const struct AttributeResultMessage *msg)
 static void
 handle_attribute_result (void *cls, const struct AttributeResultMessage *msg)
 {
-  static struct GNUNET_CRYPTO_PublicKey identity;
+  static struct GNUNET_CRYPTO_BlindablePublicKey identity;
   struct GNUNET_RECLAIM_Handle *h = cls;
   struct GNUNET_RECLAIM_AttributeIterator *it;
   struct GNUNET_RECLAIM_Operation *op;
@@ -826,7 +826,7 @@ static void
 handle_credential_result (void *cls, const struct
                           CredentialResultMessage *msg)
 {
-  struct GNUNET_CRYPTO_PublicKey identity;
+  struct GNUNET_CRYPTO_BlindablePublicKey identity;
   struct GNUNET_RECLAIM_Handle *h = cls;
   struct GNUNET_RECLAIM_CredentialIterator *it;
   struct GNUNET_RECLAIM_Operation *op;
@@ -1168,7 +1168,7 @@ GNUNET_RECLAIM_disconnect (struct GNUNET_RECLAIM_Handle *h)
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attribute_store (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *pkey,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *pkey,
   const struct GNUNET_RECLAIM_Attribute *attr,
   const struct GNUNET_TIME_Relative *exp_interval,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
@@ -1187,14 +1187,14 @@ GNUNET_RECLAIM_attribute_store (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  key_len = GNUNET_CRYPTO_private_key_get_length (pkey);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (pkey);
   attr_len = GNUNET_RECLAIM_attribute_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (sam,
                                  attr_len + key_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTRIBUTE_STORE);
   sam->key_len = htons (key_len);
   buf = (char *) &sam[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (pkey, buf, key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (pkey, buf, key_len);
   GNUNET_assert (0 < written);
   buf += written;
   sam->id = htonl (op->r_id);
@@ -1212,7 +1212,7 @@ GNUNET_RECLAIM_attribute_store (
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_attribute_delete (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *pkey,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *pkey,
   const struct GNUNET_RECLAIM_Attribute *attr,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
@@ -1230,14 +1230,14 @@ GNUNET_RECLAIM_attribute_delete (
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  key_len = GNUNET_CRYPTO_private_key_get_length (pkey);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (pkey);
   attr_len = GNUNET_RECLAIM_attribute_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (dam,
                                  attr_len + key_len,
                                  GNUNET_MESSAGE_TYPE_RECLAIM_ATTRIBUTE_DELETE);
   dam->key_len = htons (key_len);
   buf = (char *) &dam[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (pkey, buf, key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (pkey, buf, key_len);
   GNUNET_assert (0 < written);
   buf += written;
   dam->id = htonl (op->r_id);
@@ -1253,7 +1253,7 @@ GNUNET_RECLAIM_attribute_delete (
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_credential_store (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *pkey,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *pkey,
   const struct GNUNET_RECLAIM_Credential *credential,
   const struct GNUNET_TIME_Relative *exp_interval,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
@@ -1271,7 +1271,7 @@ GNUNET_RECLAIM_credential_store (
   op->as_cb = cont;
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
-  key_len = GNUNET_CRYPTO_private_key_get_length (pkey);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (pkey);
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
   attr_len = GNUNET_RECLAIM_credential_serialize_get_size (credential);
   op->env = GNUNET_MQ_msg_extra (sam,
@@ -1279,7 +1279,7 @@ GNUNET_RECLAIM_credential_store (
                                  GNUNET_MESSAGE_TYPE_RECLAIM_CREDENTIAL_STORE);
   sam->key_len = htons (key_len);
   buf = (char *) &sam[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (pkey, buf, key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (pkey, buf, key_len);
   GNUNET_assert (0 <= written);
   buf += written;
   sam->id = htonl (op->r_id);
@@ -1297,7 +1297,7 @@ GNUNET_RECLAIM_credential_store (
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_credential_delete (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *pkey,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *pkey,
   const struct GNUNET_RECLAIM_Credential *attr,
   GNUNET_RECLAIM_ContinuationWithStatus cont,
   void *cont_cls)
@@ -1314,7 +1314,7 @@ GNUNET_RECLAIM_credential_delete (
   op->as_cb = cont;
   op->cls = cont_cls;
   op->r_id = h->r_id_gen++;
-  key_len = GNUNET_CRYPTO_private_key_get_length (pkey);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (pkey);
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
   attr_len = GNUNET_RECLAIM_credential_serialize_get_size (attr);
   op->env = GNUNET_MQ_msg_extra (dam,
@@ -1322,7 +1322,7 @@ GNUNET_RECLAIM_credential_delete (
                                  GNUNET_MESSAGE_TYPE_RECLAIM_CREDENTIAL_DELETE);
   dam->key_len = htons (key_len);
   buf = (char *) &dam[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (pkey, buf, key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (pkey, buf, key_len);
   GNUNET_assert (0 <= written);
   buf += written;
   dam->id = htonl (op->r_id);
@@ -1338,7 +1338,7 @@ GNUNET_RECLAIM_credential_delete (
 struct GNUNET_RECLAIM_AttributeIterator *
 GNUNET_RECLAIM_get_attributes_start (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *identity,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *identity,
   GNUNET_SCHEDULER_TaskCallback error_cb,
   void *error_cb_cls,
   GNUNET_RECLAIM_AttributeResult proc,
@@ -1363,7 +1363,7 @@ GNUNET_RECLAIM_get_attributes_start (
   it->proc_cls = proc_cls;
   it->r_id = rid;
   it->identity = *identity;
-  key_len = GNUNET_CRYPTO_private_key_get_length (identity);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (identity);
   GNUNET_CONTAINER_DLL_insert_tail (h->it_head, h->it_tail, it);
   env =
     GNUNET_MQ_msg_extra (msg,
@@ -1371,7 +1371,7 @@ GNUNET_RECLAIM_get_attributes_start (
                          GNUNET_MESSAGE_TYPE_RECLAIM_ATTRIBUTE_ITERATION_START);
   msg->id = htonl (rid);
   msg->key_len = htons (key_len);
-  GNUNET_CRYPTO_write_private_key_to_buffer (identity, &msg[1], key_len);
+  GNUNET_CRYPTO_write_blindable_sk_to_buffer (identity, &msg[1], key_len);
   if (NULL == h->mq)
     it->env = env;
   else
@@ -1415,7 +1415,7 @@ GNUNET_RECLAIM_get_attributes_stop (struct GNUNET_RECLAIM_AttributeIterator *it)
 struct GNUNET_RECLAIM_CredentialIterator *
 GNUNET_RECLAIM_get_credentials_start (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *identity,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *identity,
   GNUNET_SCHEDULER_TaskCallback error_cb,
   void *error_cb_cls,
   GNUNET_RECLAIM_CredentialResult proc,
@@ -1440,7 +1440,7 @@ GNUNET_RECLAIM_get_credentials_start (
   ait->proc_cls = proc_cls;
   ait->r_id = rid;
   ait->identity = *identity;
-  key_len = GNUNET_CRYPTO_private_key_get_length (identity);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (identity);
   GNUNET_CONTAINER_DLL_insert_tail (h->ait_head, h->ait_tail, ait);
   env =
     GNUNET_MQ_msg_extra (msg,
@@ -1449,7 +1449,7 @@ GNUNET_RECLAIM_get_credentials_start (
   ;
   msg->id = htonl (rid);
   msg->key_len = htons (key_len);
-  GNUNET_CRYPTO_write_private_key_to_buffer (identity, &msg[1], key_len);
+  GNUNET_CRYPTO_write_blindable_sk_to_buffer (identity, &msg[1], key_len);
   if (NULL == h->mq)
     ait->env = env;
   else
@@ -1496,7 +1496,7 @@ GNUNET_RECLAIM_get_credentials_stop (struct
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_ticket_issue (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *iss,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *iss,
   const char *rp,
   const struct GNUNET_RECLAIM_AttributeList *attrs,
   GNUNET_RECLAIM_IssueTicketCallback cb,
@@ -1515,7 +1515,7 @@ GNUNET_RECLAIM_ticket_issue (
   op->ti_cb = cb;
   op->cls = cb_cls;
   op->r_id = h->r_id_gen++;
-  key_len = GNUNET_CRYPTO_private_key_get_length (iss);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (iss);
   rpk_len = strlen (rp) + 1;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
   attr_len = GNUNET_RECLAIM_attribute_list_serialize_get_size (attrs);
@@ -1525,7 +1525,7 @@ GNUNET_RECLAIM_ticket_issue (
   tim->key_len = htons (key_len);
   tim->rp_uri_len = htons (rpk_len);
   buf = (char *) &tim[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (iss, buf, key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (iss, buf, key_len);
   GNUNET_assert (0 <= written);
   buf += written;
   memcpy (buf, rp, rpk_len);
@@ -1585,7 +1585,7 @@ GNUNET_RECLAIM_ticket_consume (
 struct GNUNET_RECLAIM_TicketIterator *
 GNUNET_RECLAIM_ticket_iteration_start (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *identity,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *identity,
   GNUNET_SCHEDULER_TaskCallback error_cb,
   void *error_cb_cls,
   GNUNET_RECLAIM_TicketCallback proc,
@@ -1610,7 +1610,7 @@ GNUNET_RECLAIM_ticket_iteration_start (
   it->cls = proc_cls;
   it->r_id = rid;
 
-  key_len = GNUNET_CRYPTO_private_key_get_length (identity);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (identity);
   GNUNET_CONTAINER_DLL_insert_tail (h->ticket_it_head, h->ticket_it_tail, it);
   env = GNUNET_MQ_msg_extra (msg,
                              key_len,
@@ -1618,9 +1618,9 @@ GNUNET_RECLAIM_ticket_iteration_start (
   ;
   msg->id = htonl (rid);
   msg->key_len = htons (key_len);
-  GNUNET_CRYPTO_write_private_key_to_buffer (identity,
-                                             &msg[1],
-                                             key_len);
+  GNUNET_CRYPTO_write_blindable_sk_to_buffer (identity,
+                                              &msg[1],
+                                              key_len);
   if (NULL == h->mq)
     it->env = env;
   else
@@ -1689,7 +1689,7 @@ GNUNET_RECLAIM_ticket_iteration_stop (struct GNUNET_RECLAIM_TicketIterator *it)
 struct GNUNET_RECLAIM_Operation *
 GNUNET_RECLAIM_ticket_revoke (
   struct GNUNET_RECLAIM_Handle *h,
-  const struct GNUNET_CRYPTO_PrivateKey *identity,
+  const struct GNUNET_CRYPTO_BlindablePrivateKey *identity,
   const struct GNUNET_RECLAIM_Ticket *ticket,
   GNUNET_RECLAIM_ContinuationWithStatus cb,
   void *cb_cls)
@@ -1709,7 +1709,7 @@ GNUNET_RECLAIM_ticket_revoke (
   op->cls = cb_cls;
   op->r_id = rid;
   GNUNET_CONTAINER_DLL_insert_tail (h->op_head, h->op_tail, op);
-  key_len = GNUNET_CRYPTO_private_key_get_length (identity);
+  key_len = GNUNET_CRYPTO_blindable_sk_get_length (identity);
   tkt_len = strlen (ticket->gns_name) + 1;
   op->env = GNUNET_MQ_msg_extra (msg,
                                  key_len + tkt_len,
@@ -1718,9 +1718,9 @@ GNUNET_RECLAIM_ticket_revoke (
   msg->key_len = htons (key_len);
   msg->tkt_len = htons (tkt_len);
   buf = (char*) &msg[1];
-  written = GNUNET_CRYPTO_write_private_key_to_buffer (identity,
-                                                       buf,
-                                                       key_len);
+  written = GNUNET_CRYPTO_write_blindable_sk_to_buffer (identity,
+                                                        buf,
+                                                        key_len);
   GNUNET_assert (0 <= written);
   buf += written;
   memcpy (buf, ticket, tkt_len);
